package com.hrsk.cloud.eg.app.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.app.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.app.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.dto.data.egPlan.PlanDto;
import com.hrsk.cloud.eg.dto.data.user.UserBaseInfoDto;
import com.hrsk.cloud.eg.infrastructure.config.client.config.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.ProductBusinessApiInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.ProductBusinessApiInfoService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import com.hrsk.cloud.eg.vo.response.DataVo;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

/**
 * @Author zjc
 * @Date 2024 07 17 14 53
 **/
@Slf4j
@Component
public class QingDaoAoSengV2CreditService implements LoanDockingApi {

    @Resource
    private ProductBusinessApiInfoService apiInfoService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums  getType() {
        return ServerCodeEnums.QingDaoAoSenV2;
    }

    @Data
    private static class CheckInfo{
        private String code;
    }


    @Override
    public DataVo qualityCheck(UserBaseInfoDto userInfo, PlanDto product) {
        try {
//            log.info("credit YunHaiLianDongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
            ProductBusinessApiInfoDo apiInfo = apiInfoService.getById(product.getApiId());
            String configJson = apiInfo.getThreeSystemConfig();
            JSONObject config = JSONObject.parseObject(configJson);

            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setCode((userInfo.getPhoneMd5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getPhoneMd5()));

            String url = config.getString("checkUrl");
//            log.info("credit qualityCheck YunHaiLianDongCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            String response = null;
            try {
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            } catch (Exception e) {
                log.error("青岛奥森V2准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck QingDaoAoSenV2CreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
//            log.info("credit qualityCheck YunHaiLianDongCreditService response userId:{}, jsonObject:{}", userInfo.getUserId(), jsonObject);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 1) {
                return DataVo.success(0, "青岛奥森V2撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "青岛奥森V2撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("青岛奥森撞库失败", e);
            return DataVo.fail(1, "青岛奥森V2撞库失败，请联系系统管理员", product.getPlanId());
        }
    }
}
