package com.hrsk.cloud.eg.app.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.app.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.app.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.dto.data.egPlan.PlanDto;
import com.hrsk.cloud.eg.dto.data.user.UserBaseInfoDto;
import com.hrsk.cloud.eg.infrastructure.config.client.config.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.ProductBusinessApiInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.ProductBusinessApiInfoService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import com.hrsk.cloud.eg.vo.response.DataVo;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cglib.beans.BeanMap;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.*;


/**
 * @Descrption
 * @Author: chend
 * @Date: 2023/5/8
 * @Version V1.0
 **/
@Component
@Slf4j
public class QingyuV2CreditService implements LoanDockingApi {
    private final String qualityCheckPath = "/access/phoneMd5Check";
    private final String applyPath = "/access/customer";

    private final String prefix = "/openapi";

    @Resource
    private ProductBusinessApiInfoService apiInfoService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums  getType() {
        return ServerCodeEnums.CRM_QY_V2;
    }



    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return {"url":"http://apitest.shlyxxjs.com","key":"fluxZhudai*_key","tenantId":"1405729496904110081","trafficPlatformId":"13872425018351111"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoDto userInfo, PlanDto product) {
        try {
            log.info("credit QingyuV2CreditService qualityCheck begin...userId:{},productId={}", userInfo.getUserId(), product.getPlanId());
            ProductBusinessApiInfoDo apiInfo = apiInfoService.getById(product.getApiId());
            String configJson = apiInfo.getThreeSystemConfig();
            JSONObject config = JSONObject.parseObject(configJson);
            log.info("庆鱼V2.0对接参数:{}", JSON.toJSONString(config));
            V2Req checkInfo = new V2Req();
            checkInfo.setAccessKey(config.getString("accessKey"));
            checkInfo.setRequestId(UUID.randomUUID().toString());

            JSONObject jsonObject = new JSONObject() {{
                put("phone", userInfo.getPhoneMd5());
            }};
            JSONArray dataArray = new JSONArray();
            dataArray.add(jsonObject);
            checkInfo.setData(dataArray);
            String configUrl = config.getString("url");
            String url;
            if (configUrl.contains("qingyu3")) {
                url = config.getString("url") + qualityCheckPath;
            } else {
                url = config.getString("url") + prefix + qualityCheckPath;
            }

            log.info("credit qualityCheck QingyuV2CreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            CheckInfoResp response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, CheckInfoResp.class);
            } catch (Exception e) {
                log.error("【{}】-庆鱼V2.0准入异常,异常信息：{}", product.getPlanName(), e.getMessage(), e);
            }
            log.info("credit qualityCheck QingyuV2CreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (response.getCode() == 200 && response.getSuccess() == true && response.getData().size() == 0) {
                return DataVo.success(0, "【" + product.getPlanName() + "】-庆鱼V2.0撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(response.getMsg(), product.getPlanId());
            }
        } catch (Exception e) {
            log.error("【{}】-庆鱼V2.0撞库失败", product.getPlanName(), e);
            return DataVo.fail(1, "庆鱼V2.0撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


    public static <T> Map<String, Object> beanToMap(T bean) {
        Map<String, Object> map = new HashMap<>();
        if (bean != null) {
            BeanMap beanMap = BeanMap.create(bean);
            for (Object key : beanMap.keySet()) {
                map.put(key + "", beanMap.get(key));
            }
        }
        return map;
    }


    private String getSign(Map<String, Object> map) {
        String text = "";
        Iterator<Map.Entry<String, Object>> iterator = map.entrySet().iterator();
        while (iterator.hasNext()) {
            Map.Entry<String, Object> entry = iterator.next();
            String value;
            if (null == entry.getValue()) {
                value = "";
            } else {
                value = (String) entry.getValue();
            }
            text = text + entry.getKey() + value;
        }
        return Md5Util.encoderByMd5(text).toUpperCase();
    }


    @Data
    private static class V2Req {
        private String requestId;

        private String accessKey;

        private JSONArray data;
    }

    @Data
    private static class CheckInfoResp {
        private Integer code;
        private String msg;
        private Boolean success;
        private List<JSONObject> data;
    }


}
