package com.hrsk.cloud.eg.app.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.app.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.app.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.dto.data.egPlan.PlanDto;
import com.hrsk.cloud.eg.dto.data.user.UserBaseInfoDto;
import com.hrsk.cloud.eg.infrastructure.config.client.config.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.ProductBusinessApiInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.ProductBusinessApiInfoService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import com.hrsk.cloud.eg.vo.response.DataVo;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2024 06 06 17 11
 **/
@Slf4j
@Service
public class ShuRongCreditService implements LoanDockingApi {
    @Resource
    private ProductBusinessApiInfoService apiInfoService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums  getType() {
        return ServerCodeEnums.ShuRong;
    }

    @Data
    private static class CheckInfo {
        private String mobile;//手机号, MD5加密(32位小写)
        private String city;//城市：例如：北京
        private String source;//固定值，具体需要和对接人确定
    }


    @Data
    private static class ApplyInfoRequst {
       private String is_jm;
       private String source;
       private String data;
    }

    @Override
    public DataVo qualityCheck(UserBaseInfoDto userInfo, PlanDto product) {
        try {
            log.info("credit ShuRongCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
            ProductBusinessApiInfoDo apiInfo = apiInfoService.getById(product.getApiId());
            String configJson = apiInfo.getThreeSystemConfig();
            JSONObject config = JSONObject.parseObject(configJson);
            log.info("速融对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getPhoneMd5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getPhoneMd5();
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setMobile(phoneMd5);
            checkInfo.setSource(config.getString("source"));
            checkInfo.setCity(userInfo.getCityAllName());
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck ShuRongCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, phoneMd5);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("速融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck ShuRongCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("code").equals("100")) {
                return DataVo.success(0, "速融撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "速融撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("速融撞库失败", e);
            return DataVo.fail(1, "速融撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


}
