package com.hrsk.cloud.eg.app.threedocking.impl;
import com.hrsk.cloud.eg.app.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.app.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.dto.data.egPlan.PlanDto;
import com.hrsk.cloud.eg.dto.data.user.UserBaseInfoDto;
import com.hrsk.cloud.eg.infrastructure.config.client.config.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.ProductBusinessApiInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.ProductBusinessApiInfoService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import com.hrsk.cloud.eg.vo.response.DataVo;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.SecretKey;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.util.Base64;

/**
 * @Author Liu Tao
 * @Date 2023 11 28 11 42
 **/
@Service
@Slf4j
public class ZhongXinQiFuCreditService implements LoanDockingApi {
    @Resource
    private ProductBusinessApiInfoService apiInfoService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums  getType() {
        return ServerCodeEnums.ZhongXinQiFu;
    }
    @Data
    private static class CheckInfo{
        private String md5mobile;//md5 的手机号
        private String brand;//品牌对应数字(比如 6)
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
    {
    "checkUrl": "https://www2.zhudaicms.com/sem/check_canindb.html",
    "applyUrl": "https://www2.zhudaicms.com/sem/loan_do_aes_cbc_new.html",
    "source": "yrf-hryk",
    "brand": "1285",
    "publickey": "zhudai#aes#cbc#1",
    "iv": "2022042215123456"
    }
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoDto userInfo, PlanDto product) {
        try {
            log.info("credit ZhongXinQiFuCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
            ProductBusinessApiInfoDo apiInfo = apiInfoService.getById(product.getApiId());
            String configJson = apiInfo.getThreeSystemConfig();
            JSONObject config = JSONObject.parseObject(configJson);
            log.info("众鑫企服对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getPhoneMd5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getPhoneMd5();
            checkInfo.setMd5mobile(phoneMd5);
            checkInfo.setBrand(config.getString("brand"));
            String url = config.getString("checkUrl");
            MultiValueMap<String, String> params= new LinkedMultiValueMap<String, String>();
            params.add("md5mobile", phoneMd5);
            params.add("brand", config.getString("brand"));
            log.info("credit qualityCheck ZhongXinQiFuCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                HttpHeaders headers = new HttpHeaders();
                headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
                HttpEntity<MultiValueMap<String, String>> requestEntity = new HttpEntity<MultiValueMap<String, String>>(params, headers);
                response = httpRestTemplate.restTemplate().postForEntity(url, requestEntity, String.class).getBody();
            }catch (Exception e){
                log.error("众鑫企服准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck ZhongXinQiFuCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            if (response.equals("1")) {
                return DataVo.success(0, "众鑫企服撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "众鑫企服撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("众鑫企服撞库失败", e);
            return DataVo.fail(1, "众鑫企服撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

    public static String encrypt(String plainText, String key, String iv) throws Exception {
        // 将 key 转换为 SecretKey 对象
        SecretKey secretKey = new SecretKeySpec(key.getBytes(StandardCharsets.UTF_8), "AES");
        // 将 IV 字符串转换为字节数组
        byte[] ivBytes = iv.getBytes(StandardCharsets.UTF_8);
        // 生成 IV
        // 创建 Cipher 对象
        Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5Padding");
        cipher.init(Cipher.ENCRYPT_MODE, secretKey, new IvParameterSpec(ivBytes));
        // 加密明文
        byte[] encryptedBytes = cipher.doFinal(plainText.getBytes(StandardCharsets.UTF_8));
        // 将加密后的字节转换为 Base64 编码
        return Base64.getEncoder().encodeToString(encryptedBytes);
    }
}
